@@ -6,6 +6,7 @@ from scipy.stats import t as student_dist
 
 from ..exceptions import UserValueError
 from ..type_check import check_types
+from ..validations import validate_series_has_minimum_length
 
 
 @check_types
@@ -25,28 +26,30 @@ def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167,
     the predictor function each time.
 
     Args:
-        data (pandas.Series): Time series.
-        alpha (float, optional): Significance level.
-        bc_relaxation (float, optional): Factor.
-            Relaxation factor for the Bonferroni critical value. Smaller values will make anomaly detection more
-            conservative. Defaults to 1/6 as given in paper (gives the best results).
-        poly_order (int, optional): Polynomial order.
-            Order of the polynomial used for the regression function
+        data (pandas.Series): Time series
+        alpha (float, optional): Significance level
+            is a number higher than or equal to 0 and lower than 1. In statistics, the significance level is the
+            probability of rejecting the null hypothesis when true. For example, a significance level of 0.05 means that
+            there is a 5% risk detecting an outlier that is not a true outlier.
+        bc_relaxation (float, optional): Relaxation factor
+            for the Bonferroni critical value. Smaller values will make anomaly detection more conservative. Defaults
+            to 1/6.
+        poly_order (int, optional): Polynomial order
+            the regression function fitted to the original time series. Defaults to 3.
 
     Returns:
         pandas.Series: Time series without outliers.
 
     Raises:
-        UserValueError: Alpha needs to be betwen 0 and 1
+        UserValueError: Alpha must be a number between 0 and 1
     """
 
     # Check inputs
     data = data.dropna()
-    if len(data) < 3:
-        raise RuntimeError(f"Not enough data (got {len(data)} values) to perform operation (min 3 values required!)")
 
-    if not 0 < alpha < 1:
-        raise UserValueError("Alpha needs to be a float between 0 and 1")
+    validate_series_has_minimum_length(data, 3)
+    if not 0 <= alpha < 1:
+        raise UserValueError("Alpha must be a number between 0 and 1")
 
     # Convert datetime index to integers
     x = (np.array(data.index, dtype=np.int64) - data.index[0].value) / 1e9
@@ -68,7 +71,7 @@ def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167,
     # Determine the residuals and standardise them
     res = y - y_pred
     sse = np.sum(res ** 2)
-    t_res = res * np.sqrt(dof / (sse * (1 - hat_diagonal) - res))
+    t_res = res * np.sqrt(dof / (sse * (1 - hat_diagonal) - res ** 2))
 
     # Calculate Bonferroni critical value
     bc = student_dist.ppf(1 - alpha / (2 * n), df=dof) * bc_relaxation
