@@ -19,8 +19,8 @@ def univariate_polynomial(signal: pd.Series, coefficients: List[float] = [0.0, 1
     Args:
         signal (pandas.Series): Time series
         coefficients (List[float]): Coefficients
-            List of coefficient separated by commas. The numbers must be entered deparated by comas (e.g. 0, 1).
-            The default is :math:`0.0, 1.0`, which returns the original time series.
+            List of coefficient separated by commas. The numbers must be entered deparated by semicolons (e.g. 0; 1).
+            The default is :math:`0.0; 1.0`, which returns the original time series.
 
     Returns:
         pandas.Series: Output
